@@ -96,9 +96,10 @@ class Campaign(CreateSendBase):
     response = self._get(self.uri_for("unsubscribes"), params=params)
     return json_to_py(response)
 
-  def bounces(self, page=1, page_size=1000, order_field="date", order_direction="asc"):
+  def bounces(self, date="1900-01-01", page=1, page_size=1000, order_field="date", order_direction="asc"):
     """Retrieves the bounces for this campaign."""
     params = { 
+      "date": date,
       "page": page,
       "pagesize": page_size,
       "orderfield": order_field,
